==> risk-center-api-0.5.58-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RefererSignDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
* Referer标识页表
*/
@ApiModel
public class RefererSignDto implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("主键ID")
    private Long id;

    @ApiModelProperty("Referer标识")
    private String refererSign;

    @ApiModelProperty("标识名称")
    private String signName;

    @ApiModelProperty("修改者")
    private String tbEditor;

    @ApiModelProperty("创建时间")
    private Date gmtCreate;

    /**
    * 修改时间
    */
    @ApiModelProperty("修改时间")
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setRefererSign(String refererSign) {
        this.refererSign = refererSign;
    }

    public String getRefererSign() {
        return refererSign;
    }

    public void setSignName(String signName) {
        this.signName = signName;
    }

    public String getSignName() {
        return signName;
    }

    public void setTbEditor(String tbEditor) {
        this.tbEditor = tbEditor;
    }

    public String getTbEditor() {
        return tbEditor;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> risk-center-api-0.5.73-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RefererSignDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
* Referer标识页表
*/
@ApiModel
public class RefererSignDto implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("主键ID")
    private Long id;

    @ApiModelProperty("Referer标识")
    private String refererSign;

    @ApiModelProperty("标识名称")
    private String signName;

    @ApiModelProperty("修改者")
    private String tbEditor;

    @ApiModelProperty("创建时间")
    private Date gmtCreate;

    @ApiModelProperty("修改时间")
    private Date gmtModified;

    @ApiModelProperty("行业大类")
    private String tradeMain;

    @ApiModelProperty("行业细分")
    private String tradeSegment;

    @ApiModelProperty("是否网赚：0:否,1:是")
    private Integer lineEarnType;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setRefererSign(String refererSign) {
        this.refererSign = refererSign;
    }

    public String getRefererSign() {
        return refererSign;
    }

    public void setSignName(String signName) {
        this.signName = signName;
    }

    public String getSignName() {
        return signName;
    }

    public void setTbEditor(String tbEditor) {
        this.tbEditor = tbEditor;
    }

    public String getTbEditor() {
        return tbEditor;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getTradeMain() {
        return tradeMain;
    }

    public void setTradeMain(String tradeMain) {
        this.tradeMain = tradeMain;
    }

    public String getTradeSegment() {
        return tradeSegment;
    }

    public void setTradeSegment(String tradeSegment) {
        this.tradeSegment = tradeSegment;
    }

    public Integer getLineEarnType() {
        return lineEarnType;
    }

    public void setLineEarnType(Integer lineEarnType) {
        this.lineEarnType = lineEarnType;
    }
}
